Radio Dreams
============

|PyPI| |GitHub| |Coverage| |ReadTheDocs| |License| |Python| |Black|

-------------------------------------------------------------------

A python playground to learn how interferometers work by dreaming up imaginary arrays

*radio-dreams* is designed to install cleanly with a single invocation of the standard Python package tool::

    $ pip install radio-dreams

Here are the essential project links:

* `Home page and documentation <https://radio-dreams.readthedocs.io/en/latest/>`_

* `Installing radio-dreams <https://radio-dreams.readthedocs.io/en/latest/installation.html>`_

* `Example dreams <https://radio-dreams.readthedocs.io/en/latest/exampledreams.html>`_

* `radio-dreams package <https://pypi.org/project/radio-dreams/>`_ on the Python Package Index

* `Contributing to radio-dreams <https://github.com/amanchokshi/radio-dreams/blob/master/contrib.rst>`_

* `Issue tracker <https://github.com/amanchokshi/radio-dreams/issues>`_ on GitHub

.. |PyPI| image:: https://img.shields.io/pypi/v/radio-dreams.svg?color=green&logo=python&logoColor=white&label=PyPI
    :target: https://pypi.org/project/radio-dreams/
    :alt: PyPI - Latest Release

.. |GitHub| image:: https://img.shields.io/github/workflow/status/amanchokshi/radio-dreams/Tests?color=green&logo=github&logoColor=white&label=Tests
    :target: https://github.com/amanchokshi/radio-dreams/actions
    :alt: GitHub Actions - Build Status

.. |Coverage| image:: https://img.shields.io/codecov/c/github/amanchokshi/radio-dreams/master.svg?color=green&logo=codecov&logoColor=white&label=Coverage
    :target: https://codecov.io/gh/amanchokshi/radio-dreams/branch/main
    :alt: CodeCov - Coverage Status

.. |ReadTheDocs| image:: https://img.shields.io/readthedocs/radio-dreams/latest?color=green&logo=Read%20The%20Docs&logoColor=white
    :target: https://radio-dreams.readthedocs.io
    :alt: Documentation Status

.. |License| image:: https://img.shields.io/github/license/amanchokshi/radio-dreams?color=green&label-License&logo=data:image/png;base64, 
    :target: https://github.com/amanchokshi/radio-dreams/blob/master/LICENSE
    :alt: MIT License

.. |Python| image:: https://img.shields.io/badge/Python-3.7%2B-3282b8?logo=python&logoColor=white
    :target: https://pypi.org/project/radio-dreams/

.. |Black| image:: https://img.shields.io/badge/Code%20Style-Black-222222.svg?logo=powershell&logoColor=white
    :target: https://black.readthedocs.io/
